powered by
twed
twed(Values1, Values2, Time1, Time2, Nu = 1, Lambda = 1, Degree = 2)
List with elements
TWED distance between time series Values1 (Time1) and Values2 (Time2)
[1:n, 1:m] Numeric matrix
[1:N1] Numeric vector with values of the first time series.
[1:N1] Numeric vector with values of the second time series.
[1:N1] Numeric vector with time stamps of the first time series.
[1:N1] Numeric vector with time stamps of the second time series.
Optional, Numeric: Elasticity parameter - nu >=0 needed for distance measure.
Optional, Numeric: Penalty for deletion operation.
Optional, Integer: Degree of the p norm for local cost.
Quirin Stier
twed(1:10, 1:10, 1:10, 1:10)
Run the code above in your browser using DataLab